Package: treeSS
Type: Package
Title: Tree-Spatial Scan Statistic for Cluster Detection
Version: 0.2.6
Authors@R: c(
    person("Allan", "Quadros", email = "allanvcq@gmail.com",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-3250-5380")),
    person("Andre L. F.", "Cançado",
           role = "aut",
           comment = c(ORCID = "0000-0002-7019-8521"))
  )
Description: Implements the tree-spatial scan statistic for detecting clusters
    that combine both spatial and hierarchical structures, as proposed by
    Cancado et al. (2025) <doi:10.1007/s10651-025-00670-w>. The method extends
    Kulldorff (1997) <doi:10.1080/03610929708831995> circular spatial scan
    statistic and the tree-based scan statistic of Kulldorff et al. (2003)
    <doi:10.1111/1541-0420.00039> by searching for anomalies in both
    geographic regions and branches of hierarchical trees simultaneously. The
    package also provides standalone implementations of Kulldorff's circular
    spatial scan statistic and the tree-based scan statistic. Statistical
    significance is assessed via Monte Carlo simulation under a Poisson or
    binomial model, with optional 'OpenMP' parallelization.
License: GPL (>= 3)
URL: https://github.com/allanvc/treeSS
BugReports: https://github.com/allanvc/treeSS/issues
Depends: R (>= 3.5.0)
Imports: Rcpp (>= 1.0.0), stats
LinkingTo: Rcpp
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, sf
SystemRequirements: GNU make
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Config/testthat/edition: 3
NeedsCompilation: yes
Packaged: 2026-07-28 04:01:31 UTC; allan
Author: Allan Quadros [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3250-5380>),
  Andre L. F. Cançado [aut] (ORCID:
    <https://orcid.org/0000-0002-7019-8521>)
Maintainer: Allan Quadros <allanvcq@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-28 12:40:02 UTC
