# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

mc_treespatial_cpp <- function(full_cases, Cg, N, zone_region_idx, zone_ptr, zone_pop, leaf_tree_idx, children_idx, children_ptr, proc_order, prob, nsim, model = 0L, n_cores = 1L) {
    .Call(`_treeSS_mc_treespatial_cpp`, full_cases, Cg, N, zone_region_idx, zone_ptr, zone_pop, leaf_tree_idx, children_idx, children_ptr, proc_order, prob, nsim, model, n_cores)
}

mc_spatial_cpp <- function(cases, N, C, zone_region_idx, zone_ptr, zone_pop, prob, nsim, model = 0L, n_cores = 1L) {
    .Call(`_treeSS_mc_spatial_cpp`, cases, N, C, zone_region_idx, zone_ptr, zone_pop, prob, nsim, model, n_cores)
}

mc_treescan_cpp <- function(node_cases, node_pop, C, N, leaf_tree_idx, leaf_pop, children_idx, children_ptr, proc_order, nsim, model = 0L, n_cores = 1L) {
    .Call(`_treeSS_mc_treescan_cpp`, node_cases, node_pop, C, N, leaf_tree_idx, leaf_pop, children_idx, children_ptr, proc_order, nsim, model, n_cores)
}

